# -*- coding: utf-8 -*-

# Define here the models for your scraped items
#
# See documentation in:
# https://doc.scrapy.org/en/latest/topics/items.html

import scrapy


class CollectsportsItem(scrapy.Item):
    # define the fields for your item here like:
    zq_league = scrapy.Field()
    zq_match = scrapy.Field()
    zq_zhibo = scrapy.Field()
    zq_chain = scrapy.Field()
    zq_today = scrapy.Field()
    csource = scrapy.Field()


class ZqToday(scrapy.Item):
    match_id = scrapy.Field()
    is_roll = scrapy.Field()
    is_corner = scrapy.Field()


class ZqZhibo(scrapy.Item):
    game_type = scrapy.Field()  # 类型FT 足球，BK 篮球，vb 排球
    start_time = scrapy.Field()  # 开始时间
    host_team = scrapy.Field()  # 主队
    guest_team = scrapy.Field()  # 客队
    doing = scrapy.Field()  # 是否进行中
    showid = scrapy.Field()  # 显示id
    shower = scrapy.Field()  # 显示类型
    league_name = scrapy.Field()


class ZqLeagueItem(scrapy.Item):
    content = scrapy.Field()
    league_name = scrapy.Field()  # 联赛明称
    league_subname = scrapy.Field()  # 子联赛明称
    start_time = scrapy.Field()  # 开始时间
    team_num = scrapy.Field()  # 球队数量
    game_type = scrapy.Field()  # 联赛类型,FT ,NB
    uuid = scrapy.Field()
    league_id = scrapy.Field()
    # source = scrapy.Field()


class ZqMatch(scrapy.Item):
    match_id = scrapy.Field()
    match_name = scrapy.Field()
    host_id = scrapy.Field()
    guest_id = scrapy.Field()
    is_half = scrapy.Field()  # 是否上半场
    half_match_id = scrapy.Field()
    odds_num = scrapy.Field()  # 总玩法数量
    host_name = scrapy.Field()
    is_roll = scrapy.Field()  # 滚球
    mdate = scrapy.Field()  # 日期
    mtime = scrapy.Field()  # 时间
    is_corner = scrapy.Field()  # 是否角球
    guest_name = scrapy.Field()
    league_id = scrapy.Field()
    uuid = scrapy.Field()
    source = scrapy.Field()


class ZqChain(scrapy.Item):
    league_id = scrapy.Field()
    code = scrapy.Field()  # 赔率代码
    status = scrapy.Field()  # 未知
    name = scrapy.Field()  # 赔率名称
    odds = scrapy.Field()  # 赔率
    enabled = scrapy.Field()  # 启用状态


class Odds(scrapy.Item):
    # zq_odds = scrapy.Field()  #足球详细赔率
    match_id = scrapy.Field()
    uuid = scrapy.Field()
    source = scrapy.Field()
    updata = scrapy.Field()
    content = scrapy.Field() #足球详细玩法赔率